@@ -53,10 +53,7 @@ def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,documen
             _text = row['Object']
             predictions.append({'Text': _text, 'Label': _label})
 
-    if(len(predictions) == 0):
-        return '{}'
-    else:
-        return ConvertPredictionToJson(predictions)
+    return ConvertPredictionToJson(predictions)
 
 def load_predictionData(save_fd):
     predictions_data = torch.load(os.path.join(save_fd, 'predictions_data.dataset'))
